@@ -21,15 +21,19 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include <config.h>
 
-#include <qdir.h>
+#include <qlayout.h>
 #include <qregexp.h>
+
+#include <kapplication.h>
+#include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
+#include <kpushbutton.h>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -41,6 +45,7 @@
 #include <arpa/inet.h>
 #include <netinet/in.h>
 #include <sys/ioctl.h>
+#include <assert.h>
 
 #ifdef _XPG4_2
 #define __xnet_connect	connect
@@ -57,20 +62,17 @@
 #endif
 
 #include "auth.h"
-#include "requester.h"
 #include "connect.h"
+#include "docking.h"
 #include "main.h"
+#include "modem.h"
 #include "kpppconfig.h"
 #include "pppdata.h"
-#include "docking.h"
-#include "modem.h"
-#include "utils.h"
 #include "pppstats.h"
-#include <kapp.h>
-#include <kdebug.h>
+#include "requester.h"
+#include "utils.h"
 
 extern KPPPWidget *p_kppp;
-extern bool quit_on_disconnect;
 
 QString old_hostname;
 bool modified_hostname;
@@ -82,6 +84,7 @@ ConnectWidget::ConnectWidget(QWidget *parent, const char *name, PPPStats *st)
     myreadbuffer(""),
     main_timer_ID(0),
     vmain(0),
+    substate(-1),
     scriptindex(0),
     loopnest(0),
     loopend(false),
@@ -107,13 +110,12 @@ ConnectWidget::ConnectWidget(QWidget *parent, const char *name, PPPStats *st)
   messg = new QLabel(this, "messg");
   messg->setFrameStyle(QFrame::Panel|QFrame::Sunken);
   messg->setAlignment(AlignCenter);
-  messg->setText(i18n("Sorry, can't create modem lock file."));
+  messg->setText(i18n("Unable to create modem lock file."));
   messg->setMinimumHeight(messg->sizeHint().height() + 5);
   int messw = (messg->sizeHint().width() * 12) / 10;
   messw = QMAX(messw,280);
   messg->setMinimumWidth(messw);
-  messg->setText(i18n("Looking for Modem ..."));
-  l0->addSpacing(10);
+  messg->setText(i18n("Looking for modem..."));
   l0->addWidget(messg);
   l0->addSpacing(10);
 
@@ -121,10 +123,11 @@ ConnectWidget::ConnectWidget(QWidget *parent, const char *name, PPPStats *st)
   tl->addLayout(l1);
   l1->addStretch(1);
 
-  debug = new QPushButton(i18n("Log"), this);
+  debug = new QPushButton(i18n("&Log"), this);
+  debug->setToggleButton(true);
   connect(debug, SIGNAL(clicked()), SIGNAL(toggleDebugWindow()));
 
-  cancel = new QPushButton(i18n("Cancel"), this);
+  cancel = new QPushButton(i18n("&Cancel"), this);
   cancel->setFocus();
   connect(cancel, SIGNAL(clicked()), SLOT(cancelbutton()));
 
@@ -135,6 +138,7 @@ ConnectWidget::ConnectWidget(QWidget *parent, const char *name, PPPStats *st)
   cancel->setFixedWidth(maxw);
   l1->addWidget(debug);
   l1->addWidget(cancel);
+  l1->addSpacing(10);
 
   setFixedSize(sizeHint());
 
@@ -167,7 +171,7 @@ ConnectWidget::~ConnectWidget() {
 void ConnectWidget::preinit() {
   // this is all just to keep the GUI nice and snappy ....
   // you have to see to believe ...
-  messg->setText(i18n("Looking for Modem ..."));
+  messg->setText(i18n("Looking for modem..."));
   inittimer->start(100);
 }
 
@@ -176,6 +180,7 @@ void ConnectWidget::init() {
   gpppdata.setpppdError(0);
   inittimer->stop();
   vmain = 0;
+  substate = -1;
   expecting = false;
   pausing = false;
   scriptindex = 0;
@@ -189,7 +194,7 @@ void ConnectWidget::init() {
 
   p_kppp->con_speed = "";
 
-  quit_on_disconnect = quit_on_disconnect || gpppdata.quit_on_disconnect();
+  p_kppp->setQuitOnDisconnect (p_kppp->quitOnDisconnect() || gpppdata.quit_on_disconnect());
 
   comlist = &gpppdata.scriptType();
   arglist = &gpppdata.script();
@@ -219,13 +224,13 @@ void ConnectWidget::init() {
   int lock = Modem::modem->lockdevice();
 
   if (lock == 1) {
-    messg->setText(i18n("Sorry, modem device is locked."));
+    messg->setText(i18n("Modem device is locked."));
     vmain = 20; // wait until cancel is pressed
     return;
   }
 
   if (lock == -1) {
-    messg->setText(i18n("Sorry, can't create modem lock file."));
+    messg->setText(i18n("Unable to create modem lock file."));
     vmain = 20; // wait until cancel is pressed
     return;
   }
@@ -269,25 +274,65 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
     return;
 #endif
 
-    messg->setText(i18n("Initializing Modem..."));
-    emit debugMessage(i18n("Initializing Modem..."));
-
-    // send a carriage return and then wait a bit so that the modem will
-    // let us issue commands.
-    if(gpppdata.modemPreInitDelay() > 0) {
-      usleep(gpppdata.modemPreInitDelay() * 5000);
-      writeline("");
-      usleep(gpppdata.modemPreInitDelay() * 5000);
+    assert(PPPData::NumInitStrings > 0);
+    // first init string ?
+    if(substate == -1) {
+      messg->setText(i18n("Initializing modem..."));
+      emit debugMessage(i18n("Initializing modem..."));
+      substate = 0;
     }
-    setExpect(gpppdata.modemInitResp());
-    writeline(gpppdata.modemInitStr());
-    usleep(gpppdata.modemInitDelay() * 10000); // 0.01 - 3.0 sec
+
+    QString initStr = gpppdata.modemInitStr(substate);
+    if (!initStr.isEmpty()) {
+	// send a carriage return and then wait a bit so that the modem will
+	// let us issue commands.
+	if(gpppdata.modemPreInitDelay() > 0) {
+	    usleep(gpppdata.modemPreInitDelay() * 5000);
+	    writeline("");
+	    usleep(gpppdata.modemPreInitDelay() * 5000);
+	}
+	setExpect(gpppdata.modemInitResp());
+	writeline(initStr);
+	usleep(gpppdata.modemInitDelay() * 10000); // 0.01 - 3.0 sec
+    }
+
+    substate++;
+
+    /*
+     * FIXME after 3.0: Make it possible to disable ATS11 since it
+     * seems to be incompatible with some ISDN adapters (e.g. DataBox
+     * Speed Dragon). Even better would be to detect this when doing
+     * a "Modem Query"
+     */
+    if (MODEM_TONEDURATION != gpppdata.modemToneDuration())
+        vmain = 5;
+    else
+        vmain = 3;
+
+    return;
+  }
+
+  if (vmain == 5) {
+    if(!expecting) {
+        QString sToneDuration = "ATS11=" + QString::number(gpppdata.modemToneDuration());
+        QString msg = i18n("Setting ") + sToneDuration;
+        messg->setText(msg);
+	emit debugMessage(msg);
+	setExpect(gpppdata.modemInitResp());
+	writeline(sToneDuration);
+      }
     vmain = 3;
     return;
   }
 
   if(vmain == 3) {
     if(!expecting) {
+      // done with all init strings ?
+      if(substate < PPPData::NumInitStrings) {
+	vmain = 0;
+	return;
+      }
+      substate = -1;
       // skip setting the volume if command is empty
       if(gpppdata.volumeInitString().isEmpty()) {
         vmain = 4;
@@ -361,12 +406,12 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
       timeout_timer->stop();
       timeout_timer->start(gpppdata.modemTimeout()*1000);
 
-      messg->setText(i18n("Line Busy. Hanging up ..."));
+      messg->setText(i18n("Line busy. Hanging up..."));
       emit debugPutChar('\n');
       Modem::modem->hangup();
 
       if(gpppdata.busyWait() > 0) {
-	QString bm = i18n("Line Busy. Waiting: %1 seconds").arg(gpppdata.busyWait());
+	QString bm = i18n("Line busy. Waiting: %1 seconds").arg(gpppdata.busyWait());
 	messg->setText(bm);
 	emit debugMessage(bm);
 
@@ -378,13 +423,14 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
 
       Modem::modem->setDataMode(false);
       vmain = 0;
+      substate = -1;
       return;
     }
 
     if(readbuffer.contains(gpppdata.modemNoDialtoneResp())) {
       timeout_timer->stop();
 
-      messg->setText(i18n("No Dialtone"));
+      messg->setText(i18n("No Dial Tone"));
       vmain = 20;
       Modem::modem->unlockdevice();
       return;
@@ -398,6 +444,24 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
       Modem::modem->unlockdevice();
       return;
     }
+
+    if(readbuffer.contains(gpppdata.modemDLPResp())) {
+      timeout_timer->stop();
+
+      messg->setText(i18n("Digital Line Protection Detected."));
+      vmain = 20;
+      Modem::modem->unlockdevice();
+      KMessageBox::error(this,
+                         i18n("A Digital Line Protection (DLP) error response "
+			      "has been detected.\n"
+                              "Please disconnect the phone line.\n\n"
+                              "Do NOT connect this modem to a digital phone "
+			      "line or the modem could get permanently "
+			      "damaged"));
+      return;
+    }
+
+
   }
 
   // wait for newline after CONNECT response (so we get the speed)
@@ -488,8 +552,11 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
 	messg->setText(bm);
 	emit debugMessage(bm);
 
-        setExpect(scriptArgument);
+	// The incrementing of the scriptindex MUST be before the
+	// call to setExpect otherwise the expect will miss a string that is
+	// already in the buffer.
 	scriptindex++;
+	setExpect(scriptArgument);
         return;
       }
 
@@ -587,7 +654,7 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
 	messg->setText(bm);
 	emit debugMessage(bm);
 
-	QString pwstring = gpppdata.Password();
+	QString pwstring = gpppdata.password();
 
 	if(!pwstring.isEmpty() && firstrunPW) {
 	  // the user entered a password on the main kppp dialog
@@ -684,15 +751,19 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
 
         QString bm = i18n("Loop Start %1").arg(scriptArgument);
 
+	// The incrementing of the scriptindex MUST be before the
+	// call to setExpect otherwise the expect will miss a string that is
+	// already in the buffer.
+	scriptindex++;
+
 	if ( loopnest > (MAXLOOPNEST-2) ) {
 		bm += i18n("ERROR: Nested too deep, ignored.");
 		vmain=20;
-		scriptindex++;
 		cancelbutton();
 	        KMessageBox::error(0, i18n("Loops nested too deeply!"));
 	} else {
         	setExpect(scriptArgument);
-		loopstartindex[loopnest] = scriptindex + 1;
+		loopstartindex[loopnest] = scriptindex;
 		loopstr[loopnest] = scriptArgument;
 		loopend = false;
 		loopnest++;
@@ -700,7 +771,6 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
 	messg->setText(bm);
 	emit debugMessage(bm);
 
-	scriptindex++;
       }
 
       if (scriptCommand == "LoopEnd") {
@@ -708,11 +778,14 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
 	if ( loopnest <= 0 ) {
 		bm = i18n("LoopEnd without matching Start! Line: %1").arg(bm);
 		vmain=20;
-		scriptindex++;
 		cancelbutton();
 	        KMessageBox::error(0, bm);
 		return;
 	} else {
+	        // NB! The incrementing of the scriptindex MUST be before the
+	        // call to setExpect otherwise the expect will miss a string
+	        // that is already in the buffer.
+        	scriptindex++;
         	setExpect(scriptArgument);
 		loopnest--;
 		loopend = true;
@@ -720,7 +793,6 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
 	messg->setText(bm);
 	emit debugMessage(bm);
 
-	scriptindex++;
       }
     }
   }
@@ -789,7 +861,7 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
       semaphore = true;
       result = execppp();
 
-      emit debugMessage(i18n("Starting pppd ..."));
+      emit debugMessage(i18n("Starting pppd..."));
       kdDebug(5002) << "execppp() returned with return-code " << result << endl;
 
       if(result) {
@@ -925,7 +997,7 @@ void ConnectWidget::cancelbutton() {
     this->show();
   }
 
-  messg->setText(i18n("One Moment Please ..."));
+  messg->setText(i18n("One moment please..."));
 
   // just to be sure
   Requester::rq->removeSecret(AUTH_PAP);
@@ -952,7 +1024,7 @@ void ConnectWidget::cancelbutton() {
   }
   prompt->setConsumed();
 
-  if(quit_on_disconnect)
+  if(p_kppp->quitOnDisconnect())
     kapp->exit(0);
 }
 
@@ -975,6 +1047,7 @@ void ConnectWidget::script_timed_out() {
   p_kppp->con_win->stopClock();
 
   vmain = 0; // let's try again.
+  substate = -1;
 }
 
 
@@ -1027,7 +1100,7 @@ void ConnectWidget::pppdDied()
 }
 
 void ConnectWidget::if_waiting_slot() {
-  messg->setText(i18n("Logging on to Network ..."));
+  messg->setText(i18n("Logging on to network..."));
 
   if(!stats->ifIsUp()) {
 
@@ -1058,7 +1131,7 @@ void ConnectWidget::if_waiting_slot() {
   auto_hostname();
 
   if(!gpppdata.command_on_connect().isEmpty()) {
-    messg->setText(i18n("Running Startup Command ..."));
+    messg->setText(i18n("Running startup command..."));
 
     // make sure that we don't get any async errors
     kapp->flushX();
@@ -1181,8 +1254,8 @@ bool ConnectWidget::execppp() {
 
   if (command.length() > MAX_CMDLEN) {
     KMessageBox::error(this, i18n(
-			      "pppd command + command-line arguments exeed\n"
-			      "2024 characters in length. What are you doing?"
+			      "pppd command + command-line arguments exceed "
+			      "2024 characters in length."
 			      ));
 
     return false; // nonsensically long command which would bust my buffer buf.
