@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: general.cpp,v 1.74 2001/04/08 21:23:05 porten Exp $
+ * $Id: general.cpp,v 1.91 2003/08/29 22:24:11 jsinger Exp $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -21,27 +21,25 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-#include <qdir.h>
 #include <termios.h>
 #include <string.h>
-#include <kapp.h>
-#include <qlayout.h>
 #include <qwhatsthis.h>
 
 #include <knuminput.h>
 #include <qslider.h>
 #include "general.h"
 #include "version.h"
-#include "groupbox.h"
 #include "miniterm.h"
 #include "modeminfo.h"
 #include "modemcmds.h"
 #include "devices.h"
 #include "pppdata.h"
 #include <klocale.h>
+#include <qlayout.h>
+#include <qgrid.h>
 
 /////////////////////////////////////////////////////////////////////////////
 //
@@ -49,90 +47,82 @@
 //
 /////////////////////////////////////////////////////////////////////////////
 GeneralWidget::GeneralWidget( QWidget *parent, const char *name)
-  : KGroupBox(i18n("kppp Setup"), parent, name)
+  : QWidget(parent, name)
 {
-  QVBoxLayout *tl = new QVBoxLayout(peer(), 10, 10);
+  QVBoxLayout *tl = new QVBoxLayout(parent, 0, KDialog::spacingHint());
 
-  QHBoxLayout *verl = new QHBoxLayout(tl);
-  label1 = new QLabel(i18n("pppd Version:"), peer());
-  verl->addWidget(label1);
-  versionlabel = new QLabel(peer());
+  QHBoxLayout *hbox = new QHBoxLayout(tl);
+  QLabel *label;
+  label = new QLabel(i18n("pppd version:"), parent);
+  hbox->addWidget(label);
   QString version = gpppdata.pppdVersion();
   if(version == "0.0.0")
     version = "unknown";
-  versionlabel->setText(version);
-  versionlabel->setFrameStyle(QFrame::Sunken | QFrame::WinPanel);
-  versionlabel->setLineWidth(1);
-  verl->addWidget(versionlabel);
+  label = new QLabel(version, parent);
+  label->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
+  hbox->addWidget(label);
 
-  pppdtimeout = new KIntNumInput(gpppdata.pppdTimeout(), peer());
-  pppdtimeout->setLabel(i18n("pppd Timeout:"), AlignVCenter | AlignLeft);
-  pppdtimeout->setRange(1, TIMEOUT_SIZE, 5, false);
-  pppdtimeout->setSuffix(i18n("s"));
-  connect(pppdtimeout, SIGNAL(valueChanged(int)),
+  KIntNumInput *pppdTimeout = new KIntNumInput(gpppdata.pppdTimeout(), parent);
+  pppdTimeout->setLabel(i18n("pppd &timeout:"));
+  pppdTimeout->setRange(1, TIMEOUT_SIZE, 5, true);
+  pppdTimeout->setSuffix(i18n(" sec"));
+  connect(pppdTimeout, SIGNAL(valueChanged(int)),
           SLOT(pppdtimeoutchanged(int)));
-  tl->addWidget(pppdtimeout);
+  tl->addWidget(pppdTimeout);
   QString tmp = i18n("<i>kppp</i> will wait this number of seconds\n"
 		     "to see if a PPP connection is established.\n"
 		     "If no connection is made in this time frame,\n"
 		     "<i>kppp</i> will give up and kill pppd.");
+  QWhatsThis::add(pppdTimeout,tmp);
+  label->setBuddy(pppdTimeout);
 
-  QWhatsThis::add(pppdtimeout,tmp);
+  tl->addSpacing(10);
 
-  tl->addStretch(1);
-  QHBoxLayout *lh = new QHBoxLayout();
-  tl->addLayout(lh);
-  QVBoxLayout *l2 = new QVBoxLayout();
-  lh->addLayout(l2, 1);
-  QVBoxLayout *l3 = new QVBoxLayout();
-  lh->addLayout(l3, 0);
-  QVBoxLayout *l4 = new QVBoxLayout();
-  lh->addLayout(l4, 1);
-
-  chkbox6 = new QCheckBox(i18n("Dock into Panel on Connect"), peer());
-  QWhatsThis::add(chkbox6,
+  QCheckBox *chkBox;
+  chkBox = new QCheckBox(i18n("Doc&k into panel on connect"), parent);
+  QWhatsThis::add(chkBox,
 		  i18n("<p>After a connection is established, the\n"
 		       "window is minimized and a small icon\n"
 		       "in the KDE panel represents this window.\n"
 		       "\n"
 		       "Clicking on this icon will restore the\n"
-		       "window to it's original location and\n"
+		       "window to its original location and\n"
 		       "size."));
 
-  chkbox6->setChecked(gpppdata.get_dock_into_panel());
-  connect(chkbox6,SIGNAL(toggled(bool)),
+  chkBox->setChecked(gpppdata.get_dock_into_panel());
+  connect(chkBox,SIGNAL(toggled(bool)),
 	  this, SLOT(docking_toggled(bool)));
-  l3->addWidget(chkbox6);
+  tl->addWidget(chkBox);
 
-  chkbox2 = new QCheckBox(i18n("Automatic Redial on Disconnect"), peer());
-  chkbox2->setChecked(gpppdata.automatic_redial());
-  connect(chkbox2,SIGNAL(toggled(bool)),
+  chkBox = new QCheckBox(i18n("A&utomatic redial on disconnect"), parent);
+  chkBox->setChecked(gpppdata.automatic_redial());
+  connect(chkBox,SIGNAL(toggled(bool)),
 	  this, SLOT(redial_toggled(bool)));
-  l3->addWidget(chkbox2);
-  QWhatsThis::add(chkbox2,
+  tl->addWidget(chkBox);
+  QWhatsThis::add(chkBox,
 		  i18n("<p>When a connection is established and\n"
 		       "it somehow gets disconnected, <i>kppp</i>\n"
 		       "will try to reconnect to the same account.\n"
 		       "\n"
 		       "See <a href=\"#redial\">here</a> for more on this topic."));
 
-  chkbox3 = new QCheckBox(i18n("Show Clock on Caption"), peer());
-  chkbox3->setChecked(gpppdata.get_show_clock_on_caption());
-  connect(chkbox3, SIGNAL(toggled(bool)),
+  chkBox = new QCheckBox(i18n("&Show clock on caption"), parent);
+  chkBox->setChecked(gpppdata.get_show_clock_on_caption());
+  connect(chkBox, SIGNAL(toggled(bool)),
 	  this, SLOT(caption_toggled(bool)));
-  l3->addWidget(chkbox3);
-  QWhatsThis::add(chkbox3,
+  tl->addWidget(chkBox);
+  QWhatsThis::add(chkBox,
 		  i18n("When this option is checked, the window\n"
 		       "title shows the time since a connection\n"
 		       "was established. Very useful, so you \n"
 		       "should turn this on"));
 
-  chkbox4 = new QCheckBox(i18n("Disconnect on X-server shutdown"), peer());
-  chkbox4->setChecked(gpppdata.get_xserver_exit_disconnect());
-  connect(chkbox4, SIGNAL(toggled(bool)),
+  chkBox = new QCheckBox(i18n("Disco&nnect on X server shutdown"), parent);
+  chkBox->setChecked(gpppdata.get_xserver_exit_disconnect());
+  connect(chkBox, SIGNAL(toggled(bool)),
 	  this, SLOT(xserver_toggled(bool)));
-  l3->addWidget(chkbox4);
-  QWhatsThis::add(chkbox4,
+  tl->addWidget(chkBox);
+  QWhatsThis::add(chkBox,
 		  i18n("<p>Checking this option will close any\n"
 		       "open connection when the X-server is\n"
 		       "shut down. You should enable this option\n"
@@ -140,23 +130,25 @@ GeneralWidget::GeneralWidget( QWidget *parent, const char *name)
 		       "\n"
 		       "See <a href=\"#disxserver\">here</a> for more on this."));
 
-  chkbox7 = new QCheckBox(i18n("Quit on Disconnect"), peer());
-  chkbox7->setChecked(gpppdata.quit_on_disconnect());
-  connect(chkbox7, SIGNAL(toggled(bool)),
+  chkBox = new QCheckBox(i18n("&Quit on disconnect"), parent);
+  chkBox->setChecked(gpppdata.quit_on_disconnect());
+  connect(chkBox, SIGNAL(toggled(bool)),
 	  this, SLOT(quit_toggled(bool)));
-  l3->addWidget(chkbox7);
-  QWhatsThis::add(chkbox7,
+  tl->addWidget(chkBox);
+  QWhatsThis::add(chkBox,
 		  i18n("When this option is turned on, <i>kppp</i>\n"
 		       "will be closed when you disconnect"));
 
-  chkbox5 = new QCheckBox(i18n("Minimize Window on Connect"), peer());
-  chkbox5->setChecked(gpppdata.get_iconify_on_connect());
-  connect(chkbox5,SIGNAL(toggled(bool)),
+  chkBox = new QCheckBox(i18n("Minimi&ze window on connect"), parent);
+  chkBox->setChecked(gpppdata.get_iconify_on_connect());
+  connect(chkBox,SIGNAL(toggled(bool)),
 	  this,SLOT(iconify_toggled(bool)));
-  l3->addWidget(chkbox5);
-  QWhatsThis::add(chkbox5,
+  tl->addWidget(chkBox);
+  QWhatsThis::add(chkBox,
 		  i18n("Iconifies <i>kppp</i>'s window when a\n"
 		       "connection is established"));
+
+  tl->addStretch();
 }
 
 
@@ -196,55 +188,27 @@ void GeneralWidget::pppdtimeoutchanged(int n) {
 }
 
 
-/////////////////////////////////////////////////////////////////////////////
-//
-// The About Dialog
-//
-/////////////////////////////////////////////////////////////////////////////
-AboutWidget::AboutWidget( QWidget *parent, const char *name)
-  : KGroupBox(i18n("About kppp"), parent, name)
-{
-  QVBoxLayout *tl = new QVBoxLayout(peer(), 10);
-  QLabel *label1 = new QLabel(peer());
-  label1->setAlignment(AlignLeft|ExpandTabs);
-
-  QString string;
-  string = "kppp "KPPPVERSION;
-  string += i18n("\nA dialer and front-end to pppd\n\n"
-		 "(c) 1997, 1998\n"
-		 "    Bernd Johannes Wuebben <wuebben@kde.org>\n"
-		 "    Mario Weilguni\n"
-		 "(c) 1998-2001\n"
-		 "    Harri Porten <porten@kde.org>\n\n"
-		 "Original author: Bernd Johannes Wuebben\n"
-		 "Currently maintained by Harri Porten.\n"
-		 "Bug reports can be submitted on\n"
-		 "http://bugs.kde.org.\n\n"
-		 "This program is distributed under the GNU GPL\n"
-		 "(GNU General Public License)."
-		 );
-  label1->setText(string);
-  label1->setMinimumSize(label1->sizeHint());
-  tl->addWidget(label1);
-  tl->activate();
-}
-
-
-
 ModemWidget::ModemWidget( QWidget *parent, const char *name)
-  : KGroupBox(i18n("Serial device"), parent, name)
+  : QWidget(parent, name)
 {
   int k;
 
-  QGridLayout *tl = new QGridLayout(peer(), 9, 2, 10, 10);
+  QGridLayout *tl = new QGridLayout(parent, 8, 2, 0, KDialog::spacingHint());
 
-  label1 = new QLabel(i18n("Modem Device:"), peer());
+  label1 = new QLabel(i18n("Modem de&vice:"), parent);
   tl->addWidget(label1, 0, 0);
 
-  modemdevice = new QComboBox(false, peer());
-
+  modemdevice = new QComboBox(true, parent);
+  label1->setBuddy(modemdevice);
+  bool deviceExist = false;
   for(k = 0; devices[k]; k++)
+  {
+      if ( devices[k] == gpppdata.modemDevice())
+          deviceExist = true;
     modemdevice->insertItem(devices[k]);
+  }
+  if ( !deviceExist )
+      modemdevice->insertItem(gpppdata.modemDevice());
 
   tl->addWidget(modemdevice, 0, 1);
   connect(modemdevice, SIGNAL(activated(int)),
@@ -261,12 +225,13 @@ ModemWidget::ModemWidget( QWidget *parent, const char *name)
   QWhatsThis::add(modemdevice,tmp);
 
 
-  label2 = new QLabel(i18n("Flow Control:"), peer());
+  label2 = new QLabel(i18n("&Flow control:"), parent);
   tl->addWidget(label2, 1, 0);
 
-  flowcontrol = new QComboBox(false, peer());
-  flowcontrol->insertItem("CRTSCTS");
-  flowcontrol->insertItem("XON/XOFF");
+  flowcontrol = new QComboBox(false, parent);
+  label2->setBuddy(flowcontrol);
+  flowcontrol->insertItem(i18n("Hardware [CRTSCTS]"));
+  flowcontrol->insertItem(i18n("Software [XON/XOFF]"));
   flowcontrol->insertItem(i18n("None"));
   tl->addWidget(flowcontrol, 1, 1);
   connect(flowcontrol, SIGNAL(activated(int)),
@@ -281,16 +246,17 @@ ModemWidget::ModemWidget( QWidget *parent, const char *name)
   QWhatsThis::add(label2,tmp);
   QWhatsThis::add(flowcontrol,tmp);
 
-  labelenter = new QLabel(i18n("Line Termination:"), peer());
+  labelenter = new QLabel(i18n("&Line termination:"), parent);
   tl->addWidget(labelenter, 2, 0);
 
-  enter = new QComboBox(false, peer());
+  enter = new QComboBox(false, parent);
+  labelenter->setBuddy(enter);
   enter->insertItem("CR");
   enter->insertItem("LF");
   enter->insertItem("CR/LF");
   tl->addWidget(enter, 2, 1);
   connect(enter, SIGNAL(activated(int)), SLOT(setenter(int)));
-  tmp = i18n("<p>Specifies how AT commands are send to your\n"
+  tmp = i18n("<p>Specifies how AT commands are sent to your\n"
 	     "modem. Most modems will work fine with the\n"
 	     "default <i>CR/LF</i>. If your modem does not react\n"
 	     "to the init string, you should try different\n"
@@ -301,12 +267,10 @@ ModemWidget::ModemWidget( QWidget *parent, const char *name)
   QWhatsThis::add(labelenter,tmp);
   QWhatsThis::add(enter, tmp);
 
-  baud_label = new QLabel(i18n("Connection Speed:"), peer());
+  baud_label = new QLabel(i18n("Co&nnection speed:"), parent);
   tl->addWidget(baud_label, 3, 0);
-
-  QHBoxLayout *l1 = new QHBoxLayout;
-  tl->addLayout(l1, 3, 1);
-  baud_c = new QComboBox(peer());
+  baud_c = new QComboBox(parent);
+  baud_label->setBuddy(baud_c);
 
   static const char *baudrates[] = {
 
@@ -338,14 +302,14 @@ ModemWidget::ModemWidget( QWidget *parent, const char *name)
   baud_c->setCurrentItem(3);
   connect(baud_c, SIGNAL(activated(int)),
 	  this, SLOT(speed_selection(int)));
-  l1->addWidget(baud_c);
-  l1->addStretch(1);
+  tl->addWidget(baud_c, 3, 1);
+
   tmp = i18n("Specifies the speed your modem and the serial\n"
 	     "port talk to each other. You should begin with\n"
-	     "the default of 38400 bits/sec. If everything\n"
-	     "works you can try to increase this value, but to\n"
-	     "no more than 115200 bits/sec (unless you know\n"
-	     "that your serial port supports higher speeds).");
+	     "at least 115200 bits/sec (or more if you know\n"
+	     "that your serial port supports higher speeds).\n"
+	     "If you have connection problems, try to reduce\n"
+	     "this value.");
 
   QWhatsThis::add(baud_label,tmp);
   QWhatsThis::add(baud_c,tmp);
@@ -355,17 +319,15 @@ ModemWidget::ModemWidget( QWidget *parent, const char *name)
       enter->setCurrentItem(i);
   }
 
+  tl->addRowSpacing(4, 10);
 
   //Modem Lock File
-  modemlockfile = new QCheckBox(i18n("Use Lock File"), peer());
+  modemlockfile = new QCheckBox(i18n("&Use lock file"), parent);
 
   modemlockfile->setChecked(gpppdata.modemLockFile());
   connect(modemlockfile, SIGNAL(toggled(bool)),
           SLOT(modemlockfilechanged(bool)));
-  QHBoxLayout *l12 = new QHBoxLayout;
-  tl->addLayout(l12, 5, 0);
-  //  l12->addStretch(1);
-  l12->addWidget(modemlockfile);
+  tl->addMultiCellWidget(modemlockfile, 5, 5, 0, 1);
   //  l12->addStretch(1);
   QWhatsThis::add(modemlockfile,
 		  i18n("<p>To prevent other programs from accessing the\n"
@@ -380,10 +342,10 @@ ModemWidget::ModemWidget( QWidget *parent, const char *name)
 
   // Modem Timeout Line Edit Box
 
-  modemtimeout = new KIntNumInput(gpppdata.modemTimeout(), peer());
-  modemtimeout->setLabel(i18n("Modem Timeout:"), AlignVCenter | AlignLeft);
+  modemtimeout = new KIntNumInput(gpppdata.modemTimeout(), parent);
+  modemtimeout->setLabel(i18n("Modem &timeout:"));
   modemtimeout->setRange(1, 120, 1);
-  modemtimeout->setSuffix(i18n("s"));
+  modemtimeout->setSuffix(i18n(" sec"));
   connect(modemtimeout, SIGNAL(valueChanged(int)),
 	  SLOT(modemtimeoutchanged(int)));
   tl->addMultiCellWidget(modemtimeout, 6, 6, 0, 1);
@@ -394,6 +356,11 @@ ModemWidget::ModemWidget( QWidget *parent, const char *name)
                        "recommended value is 30 seconds."));
 
   //set stuff from gpppdata
+  for(int i=0; i <= enter->count()-1; i++) {
+    if(gpppdata.enter() == enter->text(i))
+      enter->setCurrentItem(i);
+  }
+
   for(int i=0; i <= modemdevice->count()-1; i++) {
     if(gpppdata.modemDevice() == modemdevice->text(i))
       modemdevice->setCurrentItem(i);
@@ -409,7 +376,7 @@ ModemWidget::ModemWidget( QWidget *parent, const char *name)
     if(baud_c->text(i) == gpppdata.speed())
       baud_c->setCurrentItem(i);
 
-  tl->activate();
+  tl->setRowStretch(7, 1);
 }
 
 
@@ -444,28 +411,28 @@ void ModemWidget::modemtimeoutchanged(int n) {
 
 
 ModemWidget2::ModemWidget2( QWidget *parent, const char *name)
-  : KGroupBox(i18n("Modem"), parent, name)
+  : QWidget(parent, name)
 {
-  QVBoxLayout *l1 = new QVBoxLayout(peer(), 10, 10);
+  QVBoxLayout *l1 = new QVBoxLayout(parent, 0, KDialog::spacingHint());
 
 
-  waitfordt = new QCheckBox(i18n("Wait for Dial Tone Before Dialing"), peer());
+  waitfordt = new QCheckBox(i18n("&Wait for dial tone before dialing"), parent);
   waitfordt->setChecked(gpppdata.waitForDialTone());
   connect(waitfordt, SIGNAL(toggled(bool)), SLOT(waitfordtchanged(bool)));
   l1->addWidget(waitfordt);
   QWhatsThis::add(waitfordt,
-		  i18n("Normally the modem waits for a dial tone\n"
-		       "from your phone line indicating that it can\n"
-		       "start to dial a number. If your modem doesn't\n"
-		       "recognize this sound or your local phone system\n"
-		       "doesn't emit such a tone, uncheck this option\n"
+		  i18n("<p>Normally the modem waits for a dial tone\n"
+		       "from your phone line, indicating that it can\n"
+		       "start to dial a number. If your modem does not\n"
+		       "recognize this sound, or your local phone system\n"
+		       "does not emit such a tone, uncheck this option\n"
 		       "\n"
-		       "<b>Default:</b>: on"));
+		       "<b>Default:</b>: On"));
 
-  busywait = new KIntNumInput(gpppdata.busyWait(), peer());
-  busywait->setLabel(i18n("Busy Wait:"));
-  busywait->setRange(0, 300, 5);
-  busywait->setSuffix(i18n("s"));
+  busywait = new KIntNumInput(gpppdata.busyWait(), parent);
+  busywait->setLabel(i18n("B&usy wait:"));
+  busywait->setRange(0, 300, 5, true);
+  busywait->setSuffix(i18n(" sec"));
   connect(busywait, SIGNAL(valueChanged(int)), SLOT(busywaitchanged(int)));
   l1->addWidget(busywait);
 
@@ -478,20 +445,20 @@ ModemWidget2::ModemWidget2( QWidget *parent, const char *name)
                        "The default is 0 seconds, you should not change\n"
                        "this unless you need to."));
 
-  // the checkboxes
   l1->addSpacing(10);
-  l1->addStretch(1);
 
   QHBoxLayout *hbl = new QHBoxLayout;
-  l1->addLayout(hbl);
-  QLabel *volumeLabel = new QLabel(i18n("Modem Volume:"), peer());
-  volumeLabel->setAlignment(Qt::AlignVCenter);
-  hbl->addStretch(1);
+  hbl->setSpacing(KDialog::spacingHint());
+
+  QLabel *volumeLabel = new QLabel(i18n("Modem &volume:"), parent);
   hbl->addWidget(volumeLabel);
-  volume = new QSlider(0, 2, 1, gpppdata.volume(), QSlider::Horizontal, peer());
-  volume->setFixedSize(200, 25);
+  volume = new QSlider(0, 2, 1, gpppdata.volume(), QSlider::Horizontal, parent);
+  volumeLabel->setBuddy(volume);
+  volume->setTickmarks(QSlider::Below);
   hbl->addWidget(volume);
-  hbl->addStretch(4);
+
+  l1->addLayout(hbl);
+
   connect(volume, SIGNAL(valueChanged(int)),
 	  this, SLOT(volumeChanged(int)));
   QString tmp = i18n("Most modems have a speaker which makes\n"
@@ -505,12 +472,10 @@ ModemWidget2::ModemWidget2( QWidget *parent, const char *name)
   QWhatsThis::add(volumeLabel,tmp);
   QWhatsThis::add(volume, tmp);
 
+  l1->addSpacing(20);
 
-  QHBoxLayout *l12 = new QHBoxLayout;
-  l1->addLayout(l12);
-  l12->addStretch(1);
 #if 0
-  chkbox1 = new QCheckBox(i18n("Modem Asserts CD Line."), peer());
+  chkbox1 = new QCheckBox(i18n("Modem asserts CD line"), parent);
   chkbox1->setChecked(gpppdata.UseCDLine());
   connect(chkbox1,SIGNAL(toggled(bool)),
 	  this,SLOT(use_cdline_toggled(bool)));
@@ -522,42 +487,41 @@ ModemWidget2::ModemWidget2( QWidget *parent, const char *name)
 		       "is not responding. Unless you are having\n"
 		       "problems with this, do not modify this setting.\n"
 		       "\n"
-		       "<b>Default</b>: off"));
+		       "<b>Default</b>: Off"));
 #endif
 
-  // add the buttons
-  QHBoxLayout *l11 = new QHBoxLayout;
-  l1->addLayout(l11);
-  l11->addStretch(1);
-  QVBoxLayout *l111 = new QVBoxLayout;
-  l11->addLayout(l111);
-  modemcmds = new QPushButton(i18n("Modem Commands"), peer());
+  modemcmds = new QPushButton(i18n("Mod&em Commands..."), parent);
   QWhatsThis::add(modemcmds,
 		  i18n("Allows you to change the AT command for\n"
 		       "your modem."));
 
-  modeminfo_button = new QPushButton(i18n("Query Modem"), peer());
+  modeminfo_button = new QPushButton(i18n("&Query Modem..."), parent);
   QWhatsThis::add(modeminfo_button,
 		  i18n("Most modems support the ATI command set to\n"
 		       "find out vendor and revision of your modem.\n"
 		       "\n"
 		       "Press this button to query your modem for\n"
-		       "this information.  It can be useful to help\n"
-		       "you setup the modem"));
+		       "this information. It can be useful to help\n"
+		       "you set up the modem"));
 
-  terminal_button = new QPushButton(i18n("Terminal"), peer());
+  terminal_button = new QPushButton(i18n("&Terminal..."), parent);
   QWhatsThis::add(terminal_button,
 		  i18n("Opens the built-in terminal program. You\n"
 		       "can use this if you want to play around\n"
 		       "with your modem's AT command set"));
 
-  l111->addWidget(modemcmds);
-  l111->addWidget(modeminfo_button);
-  l111->addWidget(terminal_button);
-  l11->addStretch(1);
-  l1->addStretch(1);
+  QHBoxLayout *hbox = new QHBoxLayout();
+  l1->addLayout(hbox);
+  hbox->addStretch(1);
+  QVBoxLayout *vbox = new QVBoxLayout();
+  hbox->addLayout(vbox);
 
-  l1->activate();
+  vbox->addWidget(modemcmds);
+  vbox->addWidget(modeminfo_button);
+  vbox->addWidget(terminal_button);
+
+  hbox->addStretch(1);
+  l1->addStretch(1);
 
   connect(modemcmds, SIGNAL(clicked()),
 	  SLOT(modemcmdsbutton()));
@@ -575,9 +539,8 @@ void ModemWidget2::modemcmdsbutton() {
 
 
 void ModemWidget2::query_modem() {
-  modemtrans = new ModemTransfer(this);
-  modemtrans->exec();
-  delete modemtrans;
+  ModemTransfer mt(this);
+  mt.exec();
 }
 
 
@@ -613,43 +576,46 @@ void ModemWidget2::volumeChanged(int v) {
 //
 /////////////////////////////////////////////////////////////////////////////
 GraphSetup::GraphSetup(QWidget *parent, const char *name) :
-  KCheckGroupBox(i18n("Throughput graph"), parent, name)
+  QWidget(parent, name)
 {
-  connect(this, SIGNAL(toggled(bool)), SLOT(enableToggled(bool)));
-  QGridLayout *tl = new QGridLayout(peer(), 4, 2, 10, 10);
+  QVBoxLayout *tl = new QVBoxLayout(parent);
 
   bool enable;
   QColor bg, text, in, out;
   gpppdata.graphingOptions(enable, bg, text, in, out);
 
-  bg_text = new QLabel(i18n("Background color"), peer());
-  bg_text->setAlignment(AlignRight|AlignVCenter);
-  tl->addWidget(bg_text, 0, 0);
-  bg_color = new KColorButton(bg, peer());
+  enable_check = new QCheckBox(i18n("&Enable throughput graph"), parent);
+  tl->addWidget(enable_check);
+
+  grpColor = new QGroupBox(2, Qt::Horizontal,
+        i18n("Graph Colors"), parent);
+  tl->addWidget(grpColor);
+
+  QLabel *label;
+
+  label = new QLabel(i18n("Bac&kground:"), grpColor);
+  bg_color = new KColorButton(bg, grpColor);
   bg_color->setFixedSize(80, 24);
-  tl->addWidget(bg_color, 0, 1);
+  label->setBuddy(bg_color);
 
-  text_text = new QLabel(i18n("Text color"), peer());
-  text_text->setAlignment(AlignRight|AlignVCenter);
-  tl->addWidget(text_text, 1, 0);
-  text_color = new KColorButton(text, peer());
+  label = new QLabel(i18n("&Text:"), grpColor);
+  text_color = new KColorButton(text, grpColor);
   text_color->setFixedSize(80, 24);
-  tl->addWidget(text_color, 1, 1);
+  label->setBuddy(text_color);
 
-  in_text = new QLabel(i18n("Input bytes color"), peer());
-  in_text->setAlignment(AlignRight|AlignVCenter);
-  tl->addWidget(in_text, 2, 0);
-  in_color = new KColorButton(in, peer());
+  label = new QLabel(i18n("I&nput bytes:"), grpColor);
+  in_color = new KColorButton(in, grpColor);
   in_color->setFixedSize(80, 24);
-  tl->addWidget(in_color, 2, 1);
+  label->setBuddy(in_color);
 
-  out_text = new QLabel(i18n("Output bytes color"), peer());
-  out_text->setAlignment(AlignRight|AlignVCenter);
-  tl->addWidget(out_text, 3, 0);
-  out_color = new KColorButton(out, peer());
+  label = new QLabel(i18n("O&utput bytes:"), grpColor);
+  out_color = new KColorButton(out, grpColor);
   out_color->setFixedSize(80, 24);
-  tl->addWidget(out_color, 3, 1);
+  label->setBuddy(out_color);
 
+  tl->addStretch();
+
+  connect(enable_check, SIGNAL(toggled(bool)), this, SLOT(enableToggled(bool)));
   connect(bg_color, SIGNAL(changed(const QColor &)),
 	  SLOT(colorChanged(const QColor&)));
   connect(text_color, SIGNAL(changed(const QColor &)),
@@ -661,21 +627,12 @@ GraphSetup::GraphSetup(QWidget *parent, const char *name) :
 
   tl->activate();
 
-  setChecked(enable);
+  enable_check->setChecked(enable);
   enableToggled(enable);
 }
 
 void GraphSetup::enableToggled(bool b) {
-  out_text->setEnabled(b);
-  in_text->setEnabled(b);
-  text_text->setEnabled(b);
-  bg_text->setEnabled(b);
-
-  out_color->setEnabled(b);
-  in_color->setEnabled(b);
-  bg_color->setEnabled(b);
-  text_color->setEnabled(b);
-
+  grpColor->setEnabled(b);
   save();
 }
 
@@ -684,14 +641,12 @@ void GraphSetup::colorChanged(const QColor &) {
   save();
 }
 
-
 void GraphSetup::save() {
-  gpppdata.setGraphingOptions(isChecked(),
+  gpppdata.setGraphingOptions(enable_check->isChecked(),
 			      bg_color->color(),
 			      text_color->color(),
 			      in_color->color(),
 			      out_color->color());
 }
 
-
 #include "general.moc"
