@@ -4,9 +4,6 @@
 #include "displayMgr.h"
 #include "mditoplevel.h"
 
-#include <qwidget.h>
-
-
 class DisplayMgrMDI : public QObject, public DisplayMgr
 {
     Q_OBJECT
@@ -18,7 +15,8 @@ public:
     virtual void removeTopLevel(QWidget *);
 
     virtual void show(QWidget *);
-    virtual void raise(QWidget *);
+    virtual void hide(QWidget *);
+    virtual void raise(QWidget *, bool takefocus = false);
 
     virtual void setCaption(QWidget *, const QString&);
 
@@ -26,10 +24,21 @@ public slots:
     virtual void slotCycleTabsLeft();
     virtual void slotCycleTabsRight();
 
+protected slots:
+    void reparentReq();
+    void moveWindowLeft();
+    void moveWindowRight();
+
+protected:
+    void moveWindow(int step);
+    void refreshMenuEntry();
+
 private:
     MDITopLevel *topLevel();
 
     QGuardedPtr<MDITopLevel> m_topLevel;
+    int m_moveRightTab, m_moveLeftTab;
+    QPopupMenu *m_popupWindows;
 };
 
 
